@@ -265,6 +265,8 @@ void HTMLDecoder::decodeLine(const Character* const characters, int count, LineP
                     text.append(QLatin1String("&lt;"));
                 } else if (ch == QLatin1Char('>')) {
                     text.append(QLatin1String("&gt;"));
+                } else if (ch == QLatin1Char('&')) {
+                    text.append(QLatin1String("&amp;"));
                 } else {
                     text.append(ch);
                 }
